from .utils import NoneType
from .types import *

area = Area()
blend_data = NoneType()
collection = NoneType()
engine = NoneType()
gizmo_group = NoneType()
layer_collection = NoneType()
mode = NoneType()
preferences = NoneType()
region = NoneType()
region_data = NoneType()
scene = NoneType()
screen = NoneType()
space_data = NoneType()
tool_settings = NoneType()
view_layer = NoneType()
window = NoneType()
window_manager = NoneType()
workspace = NoneType()
scene = NoneType()
view_layer = NoneType()
visible_objects = NoneType()
selectable_objects = NoneType()
selected_objects = NoneType()
editable_objects = NoneType()
selected_editable_objects = NoneType()
objects_in_mode = NoneType()
objects_in_mode_unique_data = NoneType()
visible_bones = NoneType()
editable_bones = NoneType()
selected_bones = NoneType()
selected_editable_bones = NoneType()
visible_pose_bones = NoneType()
selected_pose_bones = NoneType()
selected_pose_bones_from_active_object = NoneType()
active_bone = NoneType()
active_pose_bone = NoneType()
active_object = NoneType()
object = NoneType()
edit_object = NoneType()
sculpt_object = NoneType()
vertex_paint_object = NoneType()
weight_paint_object = NoneType()
image_paint_object = NoneType()
particle_edit_object = NoneType()
pose_object = NoneType()
sequences = NoneType()
selected_sequences = NoneType()
selected_editable_sequences = NoneType()
selected_nla_strips = NoneType()
gpencil_data = NoneType()
gpencil_data_owner = NoneType()
annotation_data = NoneType()
annotation_data_owner = NoneType()
visible_gpencil_layers = NoneType()
editable_gpencil_layers = NoneType()
editable_gpencil_strokes = NoneType()
active_gpencil_layer = NoneType()
active_gpencil_frame = NoneType()
active_annotation_layer = NoneType()
active_operator = NoneType()
visible_fcurves = NoneType()
editable_fcurves = NoneType()
selected_visible_fcurves = NoneType()
selected_editable_fcurves = NoneType()
active_editable_fcurve = NoneType()
selected_editable_keyframes = NoneType()
active_base = NoneType()
active_object = NoneType()
texture_slot = NoneType()
scene = NoneType()
world = NoneType()
object = NoneType()
mesh = NoneType()
armature = NoneType()
lattice = NoneType()
curve = NoneType()
meta_ball = NoneType()
light = NoneType()
speaker = NoneType()
lightprobe = NoneType()
camera = NoneType()
material = NoneType()
material_slot = NoneType()
texture = NoneType()
texture_user = NoneType()
texture_user_property = NoneType()
bone = NoneType()
edit_bone = NoneType()
pose_bone = NoneType()
particle_system = NoneType()
particle_system_editable = NoneType()
particle_settings = NoneType()
cloth = NoneType()
soft_body = NoneType()
fluid = NoneType()
collision = NoneType()
brush = NoneType()
dynamic_paint = NoneType()
line_style = NoneType()
collection = NoneType()
gpencil = NoneType()
volume = NoneType()
edit_image = NoneType()
edit_mask = NoneType()
selected_nodes = NoneType()
active_node = NoneType()
light = NoneType()
material = NoneType()
world = NoneType()
edit_text = NoneType()
edit_movieclip = NoneType()
edit_mask = NoneType()
edit_mask = NoneType()