from . import context
# from . import data
# from . import msgbus
# from . import ops
from . import types
# from . import utils
# from . import path
# from . import app
# from . import props

print(
"""
Note:
It is not necessary that your code will not work in bpy if it doesn't work in fake-bpy.
fake-bpy is just a module that will help check your code for missing params or incorrect method usage. 
It does not contain the data that Blender does.
""")